CREATE OR REPLACE FUNCTION updateat_trigger() RETURNS TRIGGER AS $$
BEGIN
	NEW.update_at = round(EXTRACT(EPOCH FROM now()));
	RETURN NEW;
END;
$$ language 'plpgsql';
CREATE OR REPLACE FUNCTION next_post_id(IN sequence_name varchar, IN channel_id int, OUT result bigint) AS $$
DECLARE
	seq_id int;
BEGIN
	SELECT nextval(sequence_name) INTO seq_id;
	result := channel_id;
	result := result << 32;
	result := result | (seq_id);
END;
$$ LANGUAGE PLPGSQL;
CREATE OR REPLACE FUNCTION channel_create() RETURNS trigger AS $$
BEGIN
	EXECUTE format('CREATE SCHEMA channel_%s;', NEW.id);
	EXECUTE format('CREATE SEQUENCE channel_%s.posts_id_seq;', NEW.id);
	EXECUTE format('CREATE TABLE channel_%s.posts (LIKE posts INCLUDING ALL);', NEW.id);
	EXECUTE format('ALTER TABLE channel_%s.posts ALTER COLUMN id SET DEFAULT next_post_id(''channel_%s.posts_id_seq'', %s);', NEW.id, NEW.id, NEW.id);
	EXECUTE format('ALTER TABLE channel_%s.posts ADD CONSTRAINT channel_id_chk CHECK ( channel_id = %s );', NEW.id, NEW.id);
	EXECUTE format('ALTER TABLE channel_%s.posts ADD CONSTRAINT thread_id FOREIGN KEY (thread_id) REFERENCES channel_%s.posts(id) ON DELETE CASCADE ON UPDATE CASCADE;', NEW.id, NEW.id);
	EXECUTE format('ALTER TABLE channel_%s.posts INHERIT posts;', NEW.id);
	EXECUTE format('CREATE TRIGGER channel_%s_posts_update_trigger BEFORE UPDATE ON channel_%s.posts FOR EACH ROW EXECUTE PROCEDURE post_updateat_trigger();', NEW.id, NEW.id);
	EXECUTE format('CREATE TRIGGER channel_%s_posts_delete_trigger BEFORE DELETE ON channel_%s.posts FOR EACH ROW EXECUTE PROCEDURE post_delete_trigger();', NEW.id, NEW.id);
	EXECUTE format('CREATE TRIGGER channel_%s_posts_create_trigger AFTER INSERT ON channel_%s.posts FOR EACH ROW EXECUTE PROCEDURE post_create_trigger();', NEW.id, NEW.id);
	RETURN NEW;
END;
$$ LANGUAGE plpgsql;
CREATE OR REPLACE FUNCTION channel_delete() RETURNS trigger AS $$
BEGIN
	EXECUTE format('DROP TABLE IF EXISTS channel_%s.posts CASCADE;', OLD.id);
	EXECUTE format('DROP SEQUENCE IF EXISTS channel_%s.posts_id_seq;', OLD.id);
	EXECUTE format('DROP SCHEMA IF EXISTS channel_%s CASCADE;', OLD.id);
	RETURN OLD;
END;
$$ LANGUAGE plpgsql;
CREATE OR REPLACE FUNCTION channel_update() RETURNS trigger AS $$
BEGIN
	IF OLD.total_member_count != 0 AND NEW.total_member_count = 0 AND NEW.type = 1 THEN
		NEW.close_at = round(EXTRACT(EPOCH FROM now()));
		NEW.name = NULL;
	END IF;
	RETURN NEW;
END;
$$ LANGUAGE plpgsql;
CREATE OR REPLACE FUNCTION channel_member_count_inc() RETURNS trigger AS $$
BEGIN
	UPDATE channels SET total_member_count = total_member_count + 1 WHERE id = NEW.channel_id;
	RETURN NEW;
END;
$$ LANGUAGE plpgsql;
CREATE OR REPLACE FUNCTION channel_member_count_dec() RETURNS trigger AS $$
BEGIN
	UPDATE channels SET total_member_count = total_member_count - 1 WHERE id = OLD.channel_id;
	RETURN OLD;
END;
$$ LANGUAGE plpgsql;
CREATE OR REPLACE FUNCTION post_updateat_trigger() RETURNS TRIGGER AS $$
BEGIN
	IF NEW.update_at IS NULL THEN
		NEW.update_at = round(EXTRACT(EPOCH FROM now()));
	ELSIF OLD.update_at IS NOT NULL AND NEW.update_at < OLD.update_at THEN
		RAISE EXCEPTION 'cannot update older data';
	ELSE
		NEW.update_at = OLD.update_at;
	END IF;
	IF OLD.delete_at IS NULL AND NEW.delete_at IS NOT NULL
		AND OLD.thread_id IS NOT NULL AND OLD.thread_id != OLD.id THEN
		EXECUTE format('UPDATE channel_%s.posts SET comment_count = comment_count - 1 WHERE thread_id = %s AND thread_id = id', OLD.channel_id, OLD.thread_id);
	END IF;
	RETURN NEW;
END;
$$ language 'plpgsql';
CREATE OR REPLACE FUNCTION post_delete_trigger() RETURNS trigger AS $$
BEGIN
	DELETE FROM user_stars WHERE post_id = OLD.id;
	RETURN OLD;
END;
$$ LANGUAGE plpgsql;
CREATE OR REPLACE FUNCTION post_create_trigger() RETURNS trigger AS $$
BEGIN
	UPDATE channels SET last_post_at = round(EXTRACT(EPOCH FROM now())) WHERE id = NEW.channel_id;
	IF NEW.thread_id IS NOT NULL THEN
		EXECUTE format('UPDATE channel_%s.posts SET comment_count = comment_count + 1 WHERE thread_id = %s AND thread_id = id', NEW.channel_id, NEW.thread_id);
		EXECUTE format('UPDATE channel_%s.posts SET last_comment_at = %s WHERE thread_id = %s AND thread_id = id',
			NEW.channel_id, NEW.create_at, NEW.thread_id);
	END IF;
	RETURN NEW;
END;
$$ LANGUAGE plpgsql;
CREATE OR REPLACE FUNCTION user_delete_trigger() RETURNS trigger AS $$
BEGIN
	DELETE FROM channels WHERE type = 3 AND creator_id = OLD.id;
	DELETE FROM user_stars WHERE user_id = OLD.id;
	DELETE FROM channel_members WHERE user_id = OLD.id;
	RETURN OLD;
END;
$$ LANGUAGE plpgsql;
CREATE OR REPLACE FUNCTION json2array(_j json, _key text)
  RETURNS text[] LANGUAGE sql IMMUTABLE AS
'SELECT ARRAY(SELECT elem->>_key FROM json_array_elements(_j) elem)';
CREATE TABLE sticker_categories (
	id                   serial          NOT NULL PRIMARY KEY,
	name                 text            NOT NULL UNIQUE,
	is_emoji             boolean         DEFAULT true
);
CREATE TABLE stickers (
	id                   serial          NOT NULL PRIMARY KEY,
	category_id          int             REFERENCES sticker_categories(id) ON DELETE CASCADE ON UPDATE CASCADE,
	name                 text            NOT NULL UNIQUE,
	keywords             text[]          NOT NULL DEFAULT '{}',
	support_skin         bool            DEFAULT false,
	skin_color           smallint        DEFAULT 5,
	path                 text            NOT NULL
);
CREATE INDEX stickers_category_id_key ON stickers (category_id);
CREATE VIEW view_stickers_categories AS
	SELECT S.*, SC.name AS category_name, SC.is_emoji
	FROM stickers AS S
	JOIN sticker_categories AS SC ON S.category_id = SC.id;
CREATE TABLE users (
	id                    serial         NOT NULL PRIMARY KEY,
	type                  smallint       NOT NULL,
	nickname              text           NOT NULL DEFAULT '',
	create_at             bigint         NOT NULL DEFAULT round(EXTRACT(EPOCH FROM now())),
	update_at             bigint,
	delete_at             bigint,
	avatar_version        int            DEFAULT 0
);
CREATE TABLE human (
	human_type            smallint       NOT NULL DEFAULT 0,
	props                 json,
	status                smallint       NOT NULL DEFAULT 0,
	username              text           NOT NULL
) INHERITS (users);
CREATE TABLE users_dsm (
	dsm_uid               bigint         NOT NULL UNIQUE
) INHERITS (human);
CREATE UNIQUE INDEX users_dsm_id_key ON users_dsm(id);
CREATE UNIQUE INDEX users_dsm_username_key ON users_dsm(username);
ALTER TABLE users_dsm ADD PRIMARY KEY USING INDEX users_dsm_id_key;
CREATE INDEX users_dsm_updateat_key ON users_dsm (update_at);
CREATE INDEX users_dsm_deleteat_key ON users_dsm (delete_at);
CREATE INDEX users_dsm_status_key ON users_dsm (status);
CREATE INDEX users_dsm_type_key ON users_dsm (type);
CREATE INDEX users_dsm_human_type_key ON users_dsm (human_type);
CREATE TRIGGER users_dsm_update_trigger BEFORE UPDATE ON users_dsm FOR EACH ROW EXECUTE PROCEDURE updateat_trigger();
CREATE TRIGGER users_dsm_delete_trigger BEFORE DELETE ON users_dsm FOR EACH ROW EXECUTE PROCEDURE user_delete_trigger();
CREATE TABLE channels (
	id                    serial         NOT NULL PRIMARY KEY,
	type                  smallint       NOT NULL,
	name                  text           UNIQUE,
	display_name          text,
	purpose               text,
	members               text           UNIQUE, -- a shortcut for anonymous channels
	last_post_at          bigint,
	total_member_count    int            NOT NULL DEFAULT 0,
	creator_id            bigint,
	close_at              bigint,
	create_at             bigint         NOT NULL DEFAULT round(EXTRACT(EPOCH FROM now())),
	update_at             bigint
);
CREATE INDEX channels_type_key ON channels (type);
CREATE INDEX channels_creatorid_key ON channels (creator_id);
CREATE INDEX channels_updateat_key ON channels (update_at);
CREATE INDEX channels_close_at_key ON channels (close_at);
CREATE TRIGGER channels_create_trigger AFTER INSERT ON channels FOR EACH ROW EXECUTE PROCEDURE channel_create();
CREATE TRIGGER channels_update_trigger BEFORE UPDATE ON channels FOR EACH ROW EXECUTE PROCEDURE updateat_trigger();
CREATE TRIGGER channels_update_trigger2 BEFORE UPDATE ON channels FOR EACH ROW EXECUTE PROCEDURE channel_update();
CREATE TRIGGER channels_delete_trigger BEFORE DELETE ON channels FOR EACH ROW EXECUTE PROCEDURE channel_delete();
CREATE TABLE channel_members (
	id                    serial         NOT NULL PRIMARY KEY,
	channel_id            int            NOT NULL REFERENCES channels(id) ON DELETE CASCADE ON UPDATE CASCADE,
	user_id               int            NOT NULL,
	is_star               smallint       NOT NULL DEFAULT 0,
	invitor_id            int,
	last_hide_at          bigint,
	last_view_at          bigint,
	props                 json,
	create_at             bigint         NOT NULL DEFAULT round(EXTRACT(EPOCH FROM now())),
	UNIQUE (channel_id, user_id)
);
CREATE INDEX channel_members_channelid_key ON channel_members (channel_id);
CREATE INDEX channel_members_userid_key ON channel_members (user_id);
CREATE INDEX channel_members_lastviewat_key ON channel_members (last_view_at);
CREATE INDEX channel_members_createat_key ON channel_members (create_at);
CREATE TRIGGER channel_members_count_inc AFTER INSERT ON channel_members FOR EACH ROW EXECUTE PROCEDURE channel_member_count_inc();
CREATE TRIGGER channel_members_count_dec AFTER DELETE ON channel_members FOR EACH ROW EXECUTE PROCEDURE channel_member_count_dec();
CREATE TABLE bots (
	bot_type       smallint        NOT NULL,
	token          text            UNIQUE,
	sticker_id     int             REFERENCES stickers(id) ON DELETE SET NULL ON UPDATE CASCADE,
	creator_id     int,
	is_disabled    boolean         NOT NULL DEFAULT false
) INHERITS (users);
CREATE INDEX bots_updateat_key ON bots (update_at);
CREATE INDEX bots_deleteat_key ON bots (delete_at);
CREATE INDEX bots_type_key ON bots (type);
CREATE INDEX bots_bot_type_key ON bots (bot_type);
CREATE TRIGGER bots_delete_trigger BEFORE DELETE ON bots FOR EACH ROW EXECUTE PROCEDURE user_delete_trigger();
CREATE TABLE webhook_incoming (
	channel_id     int             REFERENCES channels(id) ON DELETE CASCADE ON UPDATE CASCADE
) INHERITS (bots);
CREATE UNIQUE INDEX webhook_incoming_id_key ON webhook_incoming(id);
ALTER TABLE webhook_incoming ADD PRIMARY KEY USING INDEX webhook_incoming_id_key;
CREATE INDEX webhook_incoming_updateat_key ON webhook_incoming (update_at);
CREATE INDEX webhook_incoming_deleteat_key ON webhook_incoming (delete_at);
CREATE INDEX webhook_incoming_type_key ON webhook_incoming (type);
CREATE INDEX webhook_incoming_bot_type_key ON webhook_incoming (bot_type);
CREATE UNIQUE INDEX webhook_incoming_token_key ON webhook_incoming (token);
CREATE TRIGGER webhook_incoming_update_trigger BEFORE UPDATE ON webhook_incoming FOR EACH ROW EXECUTE PROCEDURE updateat_trigger();
CREATE TRIGGER webhook_incoming_delete_trigger BEFORE DELETE ON webhook_incoming FOR EACH ROW EXECUTE PROCEDURE user_delete_trigger();
CREATE INDEX webhook_incoming_browse_key ON webhook_incoming (create_at,delete_at);
CREATE INDEX webhook_incoming_sticker_id_key ON webhook_incoming (sticker_id);
CREATE INDEX webhook_incoming_creator_id_key ON webhook_incoming (creator_id);
CREATE INDEX webhook_incoming_channel_id_key ON webhook_incoming (channel_id);
CREATE TABLE webhook_outgoing (
	url            text,
	channel_id     int             REFERENCES channels(id) ON DELETE CASCADE ON UPDATE CASCADE,
	trigger_word   text
) INHERITS (bots);
CREATE UNIQUE INDEX webhook_outgoing_id_key ON webhook_outgoing(id);
ALTER TABLE webhook_outgoing ADD PRIMARY KEY USING INDEX webhook_outgoing_id_key;
CREATE INDEX webhook_outgoing_updateat_key ON webhook_outgoing (update_at);
CREATE INDEX webhook_outgoing_deleteat_key ON webhook_outgoing (delete_at);
CREATE INDEX webhook_outgoing_type_key ON webhook_outgoing (type);
CREATE INDEX webhook_outgoing_bot_type_key ON webhook_outgoing (bot_type);
CREATE UNIQUE INDEX webhook_outgoing_token_key ON webhook_outgoing (token);
CREATE TRIGGER webhook_outgoing_update_trigger BEFORE UPDATE ON webhook_outgoing FOR EACH ROW EXECUTE PROCEDURE updateat_trigger();
CREATE TRIGGER webhook_outgoing_delete_trigger BEFORE DELETE ON webhook_outgoing FOR EACH ROW EXECUTE PROCEDURE user_delete_trigger();
CREATE INDEX webhook_outgoing_browse_key ON webhook_outgoing (create_at,delete_at);
CREATE INDEX webhook_outgoing_sticker_id_key ON webhook_outgoing (sticker_id);
CREATE INDEX webhook_outgoing_creator_id_key ON webhook_outgoing (creator_id);
CREATE INDEX webhook_outgoing_fulltext_search_key ON webhook_outgoing USING gin(to_tsvector('simple', trigger_word));
CREATE TABLE posts (
	id                    bigint         NOT NULL PRIMARY KEY,
	user_id               int            NOT NULL,
	channel_id            int            NOT NULL,
	type                  smallint       NOT NULL,
	message               text           NOT NULL,
	full_text_search      text           NOT NULL,
	reactions             json,
	file_props            json,
	url_props             json,
	system_props          json,
	mentions              integer[],
	hashtags              text[],
	hashtags_additional   json,
	create_at             bigint         NOT NULL DEFAULT round(EXTRACT(EPOCH FROM now())),
	update_at             bigint,
	delete_at             bigint,
	thread_id             bigint,
	comment_count         int            NOT NULL DEFAULT 0,
	last_comment_at       bigint
);
CREATE INDEX posts_userid_key ON posts (user_id);
CREATE INDEX posts_channelid_key ON posts (channel_id);
CREATE INDEX posts_rootid_key ON posts (thread_id);
CREATE INDEX posts_fts_key ON posts USING GIN(to_tsvector('simple', full_text_search));
CREATE INDEX posts_type_key ON posts (type);
CREATE INDEX posts_createat_key ON posts (create_at);
CREATE INDEX posts_deleteat_key ON posts (delete_at);
CREATE INDEX posts_last_comment_at_key ON posts (last_comment_at);
CREATE INDEX posts_file_props_name ON posts ((file_props->>'name'));
CREATE INDEX posts_file_props_type ON posts ((file_props->>'type'));
CREATE INDEX posts_file_props_is_image ON posts ((file_props->>'is_image'));
CREATE INDEX posts_system_props_thread_id ON posts ((system_props->>'thread_id'));
CREATE INDEX posts_url_props_count_key ON posts (json_array_length(url_props));
CREATE INDEX posts_mentions_key ON posts USING GIN(mentions);
CREATE INDEX posts_hashtags_key ON posts USING GIN(hashtags);
CREATE TABLE user_stars (
	user_id              int             NOT NULL,
	post_id              bigint          NOT NULL,
	create_at            bigint          NOT NULL DEFAULT round(EXTRACT(EPOCH FROM now())),
	PRIMARY KEY (user_id, post_id)
);
CREATE INDEX user_stars_user_id_key ON user_stars (user_id);
CREATE INDEX user_stars_post_id_key ON user_stars (post_id);
CREATE TABLE configs (
	key                  text            NOT NULL PRIMARY KEY,
	value                text,
	update_at            bigint
);
CREATE TRIGGER config_update_trigger BEFORE UPDATE ON configs FOR EACH ROW EXECUTE PROCEDURE updateat_trigger();
INSERT INTO configs (key, value) VALUES ('version', 1);
INSERT INTO channels (type, name, display_name) VALUES (0, 'general', 'general');
INSERT INTO channels (type, name, display_name) VALUES (0, 'random', 'random');
INSERT INTO bots (type, bot_type, nickname) VALUES (0, 0, 'synobot');
INSERT INTO sticker_categories (name, is_emoji) VALUES
('face', true) ,
('food', true) ,
('transport', true) ,
('money', true) ,
('nature', true) ,
('plaints', true) ,
('animals', true) ,
('sign', true) ,
('business_man', false) ,
('business_woman', false) ;
INSERT INTO stickers (category_id, name, keywords, path) VALUES
(1, 'slightly_smiling_face', '{:D}',   'ui/images/emoji/{0}/01_01.png') ,
(1, 'rage',                  '{}',     'ui/images/emoji/{0}/01_02.png') ,
(1, 'cry',                   '{}',     'ui/images/emoji/{0}/01_03.png') ,
(1, 'smiley',                '{}',     'ui/images/emoji/{0}/01_04.png') ,
(1, 'xd',                    '{}',     'ui/images/emoji/{0}/01_05.png') ,
(1, 'neutral_face',          '{}',     'ui/images/emoji/{0}/01_06.png') ,
(1, 'sweat',                 '{}',     'ui/images/emoji/{0}/01_07.png') ,
(1, 'confused',              '{}',     'ui/images/emoji/{0}/01_08.png') ,
(1, 'fearful',               '{}',     'ui/images/emoji/{0}/01_09.png') ,
(1, 'angry',                 '{}',     'ui/images/emoji/{0}/01_10.png') ,
(1, 'wink',                  '{}',     'ui/images/emoji/{0}/01_11.png') ,
(1, 'catface',               '{}',     'ui/images/emoji/{0}/01_12.png') ,
(1, 'kidding',               '{}',     'ui/images/emoji/{0}/01_13.png') ,
(1, 'shock',                 '{}',     'ui/images/emoji/{0}/01_14.png') ,
(1, 'sob',                   '{}',     'ui/images/emoji/{0}/01_15.png') ,
(1, 'helpless',              '{}',     'ui/images/emoji/{0}/01_16.png') ,
(1, 'shy',                   '{}',     'ui/images/emoji/{0}/01_17.png') ,
(1, 'nerd_face',             '{}',     'ui/images/emoji/{0}/01_18.png') ,
(1, 'sunglasses',            '{}',     'ui/images/emoji/{0}/01_19.png') ,
(1, 'why',                   '{}',     'ui/images/emoji/{0}/01_20.png') ,
(1, 'funny',                 '{}',     'ui/images/emoji/{0}/01_21.png') ,
(1, 'sulking',               '{}',     'ui/images/emoji/{0}/01_22.png') ,
(1, 'suprised',              '{}',     'ui/images/emoji/{0}/01_23.png') ,
(1, 'pensive',               '{}',     'ui/images/emoji/{0}/01_24.png') ,
(1, 'devil',                 '{}',     'ui/images/emoji/{0}/01_25.png') ,
(1, 'angel',                 '{}',     'ui/images/emoji/{0}/01_26.png') ,
(1, 'puke',                  '{}',     'ui/images/emoji/{0}/01_27.png') ,
(1, 'grandpa',               '{}',     'ui/images/emoji/{0}/01_28.png') ,
(1, 'dizzy',                 '{}',     'ui/images/emoji/{0}/01_29.png') ,
(1, 'petrifaction',          '{}',     'ui/images/emoji/{0}/01_30.png') ,
(1, 'fish_eyes',             '{}',     'ui/images/emoji/{0}/01_31.png') ,
(1, 'heart_eyes',            '{}',     'ui/images/emoji/{0}/01_32.png') ,
(1, 'ninja',                 '{}',     'ui/images/emoji/{0}/01_33.png') ,
(1, 'hankey',       '{:poop:,:shit:}', 'ui/images/emoji/{0}/01_34.png') ,
(1, 'ghost',                 '{}',     'ui/images/emoji/{0}/01_35.png') ,
(1, 'frankenstein',          '{}',     'ui/images/emoji/{0}/01_36.png') ,
(1, 'barbarian',             '{}',     'ui/images/emoji/{0}/01_37.png') ,
(1, 'alien',                 '{}',     'ui/images/emoji/{0}/01_38.png') ,
(1, 'thumbsup',              '{:+1:}', 'ui/images/emoji/{0}/01_39.png') ,
(1, 'thumbsdown',            '{:-1:}', 'ui/images/emoji/{0}/01_40.png') ,
(2, 'hamburget',             '{}',     'ui/images/emoji/{0}/02_01.png') ,
(2, 'birthday',              '{}',     'ui/images/emoji/{0}/02_02.png') ,
(2, 'giftbox',               '{}',     'ui/images/emoji/{0}/02_03.png') ,
(2, 'coffee',                '{}',     'ui/images/emoji/{0}/02_04.png') ,
(2, 'beer',                  '{}',     'ui/images/emoji/{0}/02_05.png') ,
(2, 'fired_egg',             '{}',     'ui/images/emoji/{0}/02_06.png') ,
(2, 'apple',                 '{}',     'ui/images/emoji/{0}/02_07.png') ,
(2, 'fork_and_knife',        '{}',     'ui/images/emoji/{0}/02_08.png') ,
(3, 'ufo',                   '{}',     'ui/images/emoji/{0}/03_01.png') ,
(3, 'car',                   '{}',     'ui/images/emoji/{0}/03_02.png') ,
(3, 'metro',                 '{}',     'ui/images/emoji/{0}/03_03.png') ,
(3, 'airplane',              '{}',     'ui/images/emoji/{0}/03_04.png') ,
(3, 'rocket',                '{}',     'ui/images/emoji/{0}/03_05.png') ,
(4, 'handbag',               '{}',     'ui/images/emoji/{0}/04_01.png') ,
(4, 'ring',                  '{}',     'ui/images/emoji/{0}/04_02.png') ,
(4, 'dollar',                '{}',     'ui/images/emoji/{0}/04_03.png') ,
(5, 'star',                  '{}',     'ui/images/emoji/{0}/05_01.png') ,
(5, 'sunny',                 '{}',     'ui/images/emoji/{0}/05_02.png') ,
(5, 'crescent_moon',         '{}',     'ui/images/emoji/{0}/05_03.png') ,
(5, 'rain_cloud',            '{}',     'ui/images/emoji/{0}/05_04.png') ,
(5, 'lightning',             '{}',     'ui/images/emoji/{0}/05_05.png') ,
(6, 'palm_tree',             '{}',     'ui/images/emoji/{0}/06_01.png') ,
(6, 'cactus',                '{}',     'ui/images/emoji/{0}/06_02.png') ,
(6, 'tulip',                 '{}',     'ui/images/emoji/{0}/06_03.png') ,
(7, 'dog',                   '{}',     'ui/images/emoji/{0}/07_01.png') ,
(7, 'cat',                   '{}',     'ui/images/emoji/{0}/07_02.png') ,
(7, 'pig',                   '{}',     'ui/images/emoji/{0}/07_03.png') ,
(7, 'penguin',               '{}',     'ui/images/emoji/{0}/07_04.png') ,
(7, 'bear',                  '{}',     'ui/images/emoji/{0}/07_05.png') ,
(7, 'rabbit',                '{}',     'ui/images/emoji/{0}/07_06.png') ,
(7, 'kappa',                 '{}',     'ui/images/emoji/{0}/07_07.png') ,
(7, 'dinosaur',              '{}',     'ui/images/emoji/{0}/07_08.png') ,
(8, 'ok',                    '{}',     'ui/images/emoji/{0}/08_01.png') ,
(8, 'yes',                   '{}',     'ui/images/emoji/{0}/08_02.png') ,
(8, 'no',                    '{}',     'ui/images/emoji/{0}/08_03.png') ,
(8, '100',                   '{}',     'ui/images/emoji/{0}/08_04.png') ,
(8, 'exclamation',           '{}',     'ui/images/emoji/{0}/08_05.png') ,
(8, 'question',              '{}',     'ui/images/emoji/{0}/08_06.png') ,
(8, 'heart',                 '{<3}',   'ui/images/emoji/{0}/08_07.png') ,
(8, 'broken_heart',          '{}',     'ui/images/emoji/{0}/08_08.png');
INSERT INTO stickers (category_id, name, path) VALUES
(9, 'business_man_01', 'ui/images/sticker/business_man/01.png') ,
(9, 'business_man_02', 'ui/images/sticker/business_man/02.png') ,
(9, 'business_man_03', 'ui/images/sticker/business_man/03.png') ,
(9, 'business_man_04', 'ui/images/sticker/business_man/04.png') ,
(9, 'business_man_05', 'ui/images/sticker/business_man/05.png') ,
(9, 'business_man_06', 'ui/images/sticker/business_man/06.png') ,
(9, 'business_man_07', 'ui/images/sticker/business_man/07.png') ,
(9, 'business_man_08', 'ui/images/sticker/business_man/08.png') ,
(9, 'business_man_09', 'ui/images/sticker/business_man/09.png') ,
(9, 'business_man_10', 'ui/images/sticker/business_man/10.png') ,
(9, 'business_man_11', 'ui/images/sticker/business_man/11.png') ,
(9, 'business_man_12', 'ui/images/sticker/business_man/12.png') ,
(9, 'business_man_13', 'ui/images/sticker/business_man/13.png') ,
(9, 'business_man_14', 'ui/images/sticker/business_man/14.png') ,
(9, 'business_man_15', 'ui/images/sticker/business_man/15.png') ,
(9, 'business_man_16', 'ui/images/sticker/business_man/16.png') ,
(9, 'business_man_17', 'ui/images/sticker/business_man/17.png') ,
(9, 'business_man_18', 'ui/images/sticker/business_man/18.png') ,
(9, 'business_man_19', 'ui/images/sticker/business_man/19.png') ,
(9, 'business_man_20', 'ui/images/sticker/business_man/20.png') ,
(9, 'business_man_21', 'ui/images/sticker/business_man/21.png') ,
(10, 'business_woman_01', 'ui/images/sticker/business_woman/01.png') ,
(10, 'business_woman_02', 'ui/images/sticker/business_woman/02.png') ,
(10, 'business_woman_03', 'ui/images/sticker/business_woman/03.png') ,
(10, 'business_woman_04', 'ui/images/sticker/business_woman/04.png') ,
(10, 'business_woman_05', 'ui/images/sticker/business_woman/05.png') ,
(10, 'business_woman_06', 'ui/images/sticker/business_woman/06.png') ,
(10, 'business_woman_07', 'ui/images/sticker/business_woman/07.png') ,
(10, 'business_woman_08', 'ui/images/sticker/business_woman/08.png') ,
(10, 'business_woman_09', 'ui/images/sticker/business_woman/09.png') ,
(10, 'business_woman_10', 'ui/images/sticker/business_woman/10.png') ,
(10, 'business_woman_11', 'ui/images/sticker/business_woman/11.png') ,
(10, 'business_woman_12', 'ui/images/sticker/business_woman/12.png') ,
(10, 'business_woman_13', 'ui/images/sticker/business_woman/13.png') ,
(10, 'business_woman_14', 'ui/images/sticker/business_woman/14.png') ,
(10, 'business_woman_15', 'ui/images/sticker/business_woman/15.png') ,
(10, 'business_woman_16', 'ui/images/sticker/business_woman/16.png') ,
(10, 'business_woman_17', 'ui/images/sticker/business_woman/17.png') ,
(10, 'business_woman_18', 'ui/images/sticker/business_woman/18.png') ,
(10, 'business_woman_19', 'ui/images/sticker/business_woman/19.png') ,
(10, 'business_woman_20', 'ui/images/sticker/business_woman/20.png') ,
(10, 'business_woman_21', 'ui/images/sticker/business_woman/21.png') ;
