CREATE OR REPLACE FUNCTION post_create_before_trigger() RETURNS trigger AS $$
BEGIN
	IF NEW.id IS NULL THEN
		NEW.id = next_post_id('channel_' || NEW.channel_id || '.posts_id_seq', NEW.channel_id);
	END IF;
	RETURN NEW;
END;
$$ LANGUAGE plpgsql;
CREATE OR REPLACE FUNCTION post_create_trigger() RETURNS trigger AS $$
BEGIN
	UPDATE channels SET last_post_at = get_time_ms() WHERE id = NEW.channel_id;
	IF NEW.thread_id IS NOT NULL THEN
		EXECUTE format('UPDATE posts SET thread_id = id, comment_count = comment_count + 1 WHERE id = %s', NEW.thread_id);
		EXECUTE format('UPDATE posts SET last_comment_at = %s WHERE thread_id = %s AND thread_id = id', NEW.create_at, NEW.thread_id);
	END IF;
	RETURN NEW;
END;
$$ LANGUAGE plpgsql;
CREATE OR REPLACE FUNCTION post_updateat_trigger() RETURNS TRIGGER AS $$
BEGIN
	IF NEW.update_at IS NULL AND OLD.message != NEW.message THEN
		NEW.update_at = get_time_ms();
	ELSIF OLD.update_at IS NOT NULL AND NEW.update_at < OLD.update_at THEN
		RAISE EXCEPTION 'cannot update older data';
	ELSE
		NEW.update_at = OLD.update_at;
	END IF;
	IF OLD.delete_at IS NULL AND NEW.delete_at IS NOT NULL
		AND OLD.thread_id IS NOT NULL AND OLD.thread_id != OLD.id THEN
		EXECUTE format('UPDATE posts SET comment_count = comment_count - 1 WHERE id = %s', OLD.thread_id);
	END IF;
	RETURN NEW;
END;
$$ language 'plpgsql';
CREATE OR REPLACE FUNCTION channel_create() RETURNS trigger AS $$
BEGIN
	EXECUTE format('CREATE SCHEMA channel_%s;', NEW.id);
	EXECUTE format('CREATE SEQUENCE channel_%s.posts_id_seq;', NEW.id);
	EXECUTE format('CREATE VIEW channel_%s.view_posts AS SELECT * FROM posts WHERE channel_id = %s;', NEW.id, NEW.id);
	EXECUTE format('CREATE VIEW channel_%s.view_current_posts AS SELECT * FROM posts WHERE channel_id = %s AND id >= (SELECT post_id_since FROM channels WHERE id = %s);', NEW.id, NEW.id, NEW.id);
	EXECUTE format('CREATE VIEW channel_%s.view_subscribed_comments AS SELECT post.*, subscribes.user_id AS subscribe_user_id FROM channel_%s.view_current_posts AS post JOIN user_subscribes AS subscribes ON post.thread_id = subscribes.post_id AND post.create_at > subscribes.create_at AND post.thread_id != post.id;', NEW.id, NEW.id);
	RETURN NEW;
END;
$$ LANGUAGE plpgsql;
CREATE OR REPLACE FUNCTION channel_delete() RETURNS trigger AS $$
BEGIN
	EXECUTE format('DELETE FROM posts WHERE channel_id = %s;', OLD.id);
	EXECUTE format('DROP VIEW IF EXISTS channel_%s.view_subscribed_comments;', OLD.id);
	EXECUTE format('DROP VIEW IF EXISTS channel_%s.view_current_posts;', OLD.id);
	EXECUTE format('DROP VIEW IF EXISTS channel_%s.view_posts;', OLD.id);
	EXECUTE format('DROP SEQUENCE IF EXISTS channel_%s.posts_id_seq;', OLD.id);
	EXECUTE format('DROP SCHEMA IF EXISTS channel_%s CASCADE;', OLD.id);
	RETURN OLD;
END;
$$ LANGUAGE plpgsql;
CREATE INDEX posts_is_sticky_key ON posts (is_sticky);
CREATE INDEX posts_channel_userid_key ON posts (channel_id, user_id);
CREATE INDEX posts_channel_rootid_key ON posts (channel_id, thread_id);
CREATE INDEX posts_channel_type_key ON posts (channel_id, type);
CREATE INDEX posts_channel_createat_key ON posts (channel_id, create_at);
CREATE INDEX posts_channel_deleteat_key ON posts (channel_id, delete_at);
CREATE INDEX posts_channel_last_comment_at_key ON posts (channel_id, last_comment_at);
CREATE INDEX posts_channel_file_props_name ON posts (channel_id, (file_props->>'name'));
CREATE INDEX posts_channel_file_props_type ON posts (channel_id, (file_props->>'type'));
CREATE INDEX posts_channel_file_props_is_image ON posts (channel_id, (file_props->>'is_image'));
CREATE INDEX posts_channel_system_props_thread_id ON posts (channel_id, (system_props->>'thread_id'));
CREATE INDEX posts_channel_url_props_count_key ON posts (channel_id, json_array_length(url_props));
CREATE INDEX posts_channel_root_id_key ON posts (channel_id, thread_id);
CREATE INDEX posts_channel_last_pin_at_key ON posts (channel_id, last_pin_at);
CREATE INDEX posts_channel_is_sticky_key ON posts (channel_id, is_sticky);
CREATE TRIGGER posts_create_before_trigger BEFORE INSERT ON posts FOR EACH ROW EXECUTE PROCEDURE post_create_before_trigger();
CREATE TRIGGER posts_create_trigger AFTER INSERT ON posts FOR EACH ROW EXECUTE PROCEDURE post_create_trigger();
CREATE TRIGGER posts_delete_trigger BEFORE DELETE ON posts FOR EACH ROW EXECUTE PROCEDURE post_delete_trigger();
CREATE TRIGGER posts_update_trigger BEFORE UPDATE ON posts FOR EACH ROW EXECUTE PROCEDURE post_updateat_trigger();
CREATE TABLE user_subscribes (
	user_id       int      NOT NULL,
	post_id       bigint   NOT NULL REFERENCES posts(id) ON DELETE CASCADE ON UPDATE CASCADE,
	channel_id    int      NOT NULL REFERENCES channels(id) ON DELETE CASCADE ON UPDATE CASCADE,
	create_at     bigint   NOT NULL DEFAULT get_time_ms(),
	PRIMARY KEY (user_id, post_id)
);
CREATE INDEX user_subscribes_user_id_key ON user_subscribes (user_id);
CREATE INDEX user_subscribes_post_id_key ON user_subscribes (post_id);
CREATE INDEX user_subscribes_channel_id_key ON user_subscribes (channel_id);
CREATE INDEX user_subscribes_user_channel_key ON user_subscribes (user_id, channel_id);
CREATE INDEX user_subscribes_user_create_at_key ON user_subscribes (create_at);
ALTER TABLE channel_members ADD COLUMN last_view_comment_at bigint NOT NULL DEFAULT get_time_ms();
CREATE OR REPLACE RULE insert_ignore_on_user_subscribes AS
ON INSERT TO user_subscribes
WHERE EXISTS (SELECT 1 FROM user_subscribes WHERE user_id = NEW.user_id AND post_id = NEW.post_id)
DO INSTEAD NOTHING;
